==> libosl_0.4.3.orig.tar.gz: libosl_0.4.3.orig/doc/html/search/variables_6b.js <==
var searchData=
[
  ['key',['key',['../structosl_1_1checkmate_1_1Dfpn_1_1ProofOracle.html#a3a3d951fa23fa2eb019137982bce7c41',1,'osl::checkmate::Dfpn::ProofOracle::key()'],['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a9c5ba2ccab8a8c8009ceeb1fbad6d482',1,'osl::ntesuki::NtesukiRecord::key()']]],
  ['keys',['keys',['../classosl_1_1record_1_1CheckDuplicate.html#a59a1c7f450a067e7bbe8fc33117df870',1,'osl::record::CheckDuplicate']]],
  ['killer_5fmoves',['killer_moves',['../classosl_1_1search_1_1BigramKillerMove.html#a6d5892c43456c5bd037bfe12315cfcc9',1,'osl::search::BigramKillerMove::killer_moves()'],['../classosl_1_1search_1_1KillerMoveTable.html#a2d7c5e5ac7c9243219bf1f13c9d77f61',1,'osl::search::KillerMoveTable::killer_moves()'],['../structosl_1_1search_1_1SearchState2Shared.html#ad2ed4163722cea8f9cdb6e4d008ab1a8',1,'osl::search::SearchState2Shared::killer_moves()']]],
  ['killermovemax',['KillerMoveMax',['../classosl_1_1search_1_1KillerMoveTable.html#a81d859f9036dc5035cedb762517962b8',1,'osl::search::KillerMoveTable']]],
  ['killers',['killers',['../structosl_1_1search_1_1AlphaBeta2Common.html#ae6d693e95b035da716bf343792996678',1,'osl::search::AlphaBeta2Common']]],
  ['king25_5fboth_5fside',['king25_both_side',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a4e50955f2b68346e2b45d0e829bea078',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king25_5feffect_5feach',['king25_effect_each',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a2a562217bd2eb749906222d5f105b524',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king3pieces',['king3pieces',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#ae1056fde594bef9d8bdacd9eb346c398',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king8_5fattack_5fbonus',['king8_attack_bonus',['../structosl_1_1eval_1_1ProgressDebugInfo.html#aa915f517f17b9009acab8603777286d6',1,'osl::eval::ProgressDebugInfo']]],
  ['king8_5flong_5fpieces',['king8_long_pieces',['../structosl_1_1move__probability_1_1StateInfo.html#a6abfc5fc099820067f48cffe8955fc42',1,'osl::move_probability::StateInfo']]],
  ['king8infos',['king8infos',['../classosl_1_1state_1_1NumEffectState.html#a6ba8b9279901490ffc240a25177e46cd',1,'osl::state::NumEffectState']]],
  ['king_5fescape_5fhistogram',['king_escape_histogram',['../ratingstat_8cc.html#abb08b6bc1897ce11840a590378a0fb6a',1,'ratingstat.cc']]],
  ['king_5fmobility',['king_mobility',['../classosl_1_1state_1_1NumEffectState.html#a62b292b5d76ec5719bac73170dbd9ff2',1,'osl::state::NumEffectState']]],
  ['king_5fpieces',['king_pieces',['../classosl_1_1record_1_1MiniBoard.html#a7bb4af6cc10bd6877efa0556ebf068aa',1,'osl::record::MiniBoard']]],
  ['king_5frelative_5fattack',['king_relative_attack',['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#ab796fcea462755c2ca3645e92135d70f',1,'osl::progress::ml::NewProgressData']]],
  ['king_5frelative_5fdefense',['king_relative_defense',['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#a872402bdfbd5e249f0c03d197f28c34a',1,'osl::progress::ml::NewProgressData']]],
  ['king_5frelative_5fweight',['king_relative_weight',['../classosl_1_1progress_1_1ml_1_1NewProgress.html#ae464f814a81804e8e5e0fbae79dd41e1',1,'osl::progress::ml::NewProgress']]],
  ['king_5frook_5fbishop',['king_rook_bishop',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#acebb55d8f90a78c9994c8d62fa20fda3',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king_5fstatus',['king_status',['../classosl_1_1search_1_1DualThreatmateState.html#a341d0db50cc5f3263186d11a1083c467',1,'osl::search::DualThreatmateState']]],
  ['king_5ftable',['king_table',['../classosl_1_1eval_1_1ml_1_1BishopHead.html#aff9a030496b2c1c4e4e69521b4fbc8b4',1,'osl::eval::ml::BishopHead::king_table()'],['../classosl_1_1eval_1_1ml_1_1NonPawnAttacked.html#a779c11e8c53c89e3c909cae55383f506',1,'osl::eval::ml::NonPawnAttacked::king_table()']]],
  ['king_5ftable_5fvalue',['king_table_value',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a19cf0d4d443999830bef053e0808e06f',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['kingescape_5forder',['kingescape_order',['../ratingstat_8cc.html#acf94cd17bd622a9becfc3d35f6cfb5ae',1,'ratingstat.cc']]],
  ['kingescape_5forder_5fall',['kingescape_order_all',['../ratingstat_8cc.html#a3e9ca19691651f9a2916d45c4f2407cf',1,'ratingstat.cc']]],
  ['kingescape_5forder_5fselected',['kingescape_order_selected',['../ratingstat_8cc.html#af9351a84d6983312d404c98c77fe7c02',1,'ratingstat.cc']]],
  ['kingx_5fblocked',['kingx_blocked',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#ab89fa8f61df9b83dac88f75dd3d273d8',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['kisen_5ffilename',['kisen_filename',['../classosl_1_1rating_1_1BradleyTerry.html#a1d7c7a857bff7d91a532c811ecaf08a2',1,'osl::rating::BradleyTerry::kisen_filename()'],['../probability_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;probability.cc'],['../ratingstat_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;ratingstat.cc']]],
  ['kisen_5fstart',['kisen_start',['../classosl_1_1rating_1_1BradleyTerry.html#adb84216c75da157172c0beae9901d122',1,'osl::rating::BradleyTerry::kisen_start()'],['../ratingstat_8cc.html#a986af9c47cde7151fd744d6b235d3d14',1,'kisen_start():&#160;ratingstat.cc']]],
  ['kmove',['kmove',['../classosl_1_1record_1_1ki2_1_1InputStream.html#af78116db5d99c09a067130df2155fa1b',1,'osl::record::ki2::InputStream']]],
  ['knight_5fadvance',['knight_advance',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aeba406eec6c99383a0400c27357a32e9',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fbonus',['knight_bonus',['../structosl_1_1eval_1_1MinorPieceDebugInfo.html#a1ce25ac27db449a3fedd83d5d350215c',1,'osl::eval::MinorPieceDebugInfo']]],
  ['knight_5fcheck',['knight_check',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a764c08e418edc7b632d708c163337ffa',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fcheck_5fbonus',['knight_check_bonus',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a12766e07d3848aa0470e14f1a84e72f4',1,'osl::eval::ProgressDebugInfo']]],
  ['knight_5fdrop',['knight_drop',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a9565549637d50a8a90b560569fdb45c1',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5ffork_5fsquares',['knight_fork_squares',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aef07b44ed27f2c85681175bc5378162c',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fhead',['knight_head',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a80203477136176d1fdfda0cc4beaa0ae',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fon_5fstand',['knight_on_stand',['../classosl_1_1eval_1_1MinorPieceBonus.html#a2edbb8b0bea77db4f87100183f5e8dc4',1,'osl::eval::MinorPieceBonus']]],
  ['knight_5fpieces',['knight_pieces',['../classosl_1_1record_1_1MiniBoard.html#a7b1f0fa9a42ec524d6c0df9813234947',1,'osl::record::MiniBoard']]],
  ['knight_5ftable',['knight_table',['../classosl_1_1eval_1_1ml_1_1GoldFeatures.html#addd0581a233acd454a6dc0ad67895865',1,'osl::eval::ml::GoldFeatures']]]
];

==> libosl_0.6.0.orig.tar.gz: libosl_0.6.0.orig/doc/html/search/variables_6b.js <==
var searchData=
[
  ['key',['key',['../structosl_1_1checkmate_1_1Dfpn_1_1ProofOracle.html#a3a3d951fa23fa2eb019137982bce7c41',1,'osl::checkmate::Dfpn::ProofOracle::key()'],['../classosl_1_1hash_1_1HashGenTable.html#a5bb93f9b22e42480e436988e3c4a177e',1,'osl::hash::HashGenTable::key()'],['../classosl_1_1ntesuki_1_1NtesukiRecord.html#a9c5ba2ccab8a8c8009ceeb1fbad6d482',1,'osl::ntesuki::NtesukiRecord::key()']]],
  ['keys',['keys',['../classosl_1_1record_1_1CheckDuplicate.html#a59a1c7f450a067e7bbe8fc33117df870',1,'osl::record::CheckDuplicate']]],
  ['killer_5fmoves',['killer_moves',['../classosl_1_1search_1_1BigramKillerMove.html#a6d5892c43456c5bd037bfe12315cfcc9',1,'osl::search::BigramKillerMove::killer_moves()'],['../classosl_1_1search_1_1KillerMoveTable.html#a2d7c5e5ac7c9243219bf1f13c9d77f61',1,'osl::search::KillerMoveTable::killer_moves()'],['../structosl_1_1search_1_1SearchState2Shared.html#ad2ed4163722cea8f9cdb6e4d008ab1a8',1,'osl::search::SearchState2Shared::killer_moves()']]],
  ['killermovemax',['KillerMoveMax',['../classosl_1_1search_1_1KillerMoveTable.html#a81d859f9036dc5035cedb762517962b8',1,'osl::search::KillerMoveTable']]],
  ['killers',['killers',['../structosl_1_1search_1_1AlphaBeta2Common.html#ae6d693e95b035da716bf343792996678',1,'osl::search::AlphaBeta2Common']]],
  ['king25_5fboth_5fside',['king25_both_side',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a4e50955f2b68346e2b45d0e829bea078',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king25_5feffect_5feach',['king25_effect_each',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a2a562217bd2eb749906222d5f105b524',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king3pieces',['king3pieces',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#ae1056fde594bef9d8bdacd9eb346c398',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king8_5fattack_5fbonus',['king8_attack_bonus',['../structosl_1_1eval_1_1ProgressDebugInfo.html#aa915f517f17b9009acab8603777286d6',1,'osl::eval::ProgressDebugInfo']]],
  ['king8_5flong_5fpieces',['king8_long_pieces',['../structosl_1_1move__probability_1_1StateInfo.html#a6abfc5fc099820067f48cffe8955fc42',1,'osl::move_probability::StateInfo']]],
  ['king8infos',['king8infos',['../classosl_1_1state_1_1NumEffectState.html#a6ba8b9279901490ffc240a25177e46cd',1,'osl::state::NumEffectState']]],
  ['king_5fescape_5fhistogram',['king_escape_histogram',['../ratingstat_8cc.html#abb08b6bc1897ce11840a590378a0fb6a',1,'ratingstat.cc']]],
  ['king_5fmobility',['king_mobility',['../classosl_1_1state_1_1NumEffectState.html#a62b292b5d76ec5719bac73170dbd9ff2',1,'osl::state::NumEffectState']]],
  ['king_5fpieces',['king_pieces',['../classosl_1_1record_1_1MiniBoard.html#a7bb4af6cc10bd6877efa0556ebf068aa',1,'osl::record::MiniBoard']]],
  ['king_5frelative_5fattack',['king_relative_attack',['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#ab796fcea462755c2ca3645e92135d70f',1,'osl::progress::ml::NewProgressData']]],
  ['king_5frelative_5fdefense',['king_relative_defense',['../structosl_1_1progress_1_1ml_1_1NewProgressData.html#a872402bdfbd5e249f0c03d197f28c34a',1,'osl::progress::ml::NewProgressData']]],
  ['king_5frelative_5fweight',['king_relative_weight',['../classosl_1_1progress_1_1ml_1_1NewProgress.html#ae464f814a81804e8e5e0fbae79dd41e1',1,'osl::progress::ml::NewProgress']]],
  ['king_5frook_5fbishop',['king_rook_bishop',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#acebb55d8f90a78c9994c8d62fa20fda3',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['king_5fstatus',['king_status',['../classosl_1_1search_1_1DualThreatmateState.html#a341d0db50cc5f3263186d11a1083c467',1,'osl::search::DualThreatmateState']]],
  ['king_5ftable',['king_table',['../classosl_1_1eval_1_1ml_1_1BishopHead.html#aff9a030496b2c1c4e4e69521b4fbc8b4',1,'osl::eval::ml::BishopHead::king_table()'],['../classosl_1_1eval_1_1ml_1_1NonPawnAttacked.html#a779c11e8c53c89e3c909cae55383f506',1,'osl::eval::ml::NonPawnAttacked::king_table()']]],
  ['king_5ftable_5fvalue',['king_table_value',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a19cf0d4d443999830bef053e0808e06f',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['kingescape_5forder',['kingescape_order',['../ratingstat_8cc.html#acf94cd17bd622a9becfc3d35f6cfb5ae',1,'ratingstat.cc']]],
  ['kingescape_5forder_5fall',['kingescape_order_all',['../ratingstat_8cc.html#a3e9ca19691651f9a2916d45c4f2407cf',1,'ratingstat.cc']]],
  ['kingescape_5forder_5fselected',['kingescape_order_selected',['../ratingstat_8cc.html#af9351a84d6983312d404c98c77fe7c02',1,'ratingstat.cc']]],
  ['kingx_5fblocked',['kingx_blocked',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#ab89fa8f61df9b83dac88f75dd3d273d8',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['kisen_5ffilename',['kisen_filename',['../classosl_1_1rating_1_1BradleyTerry.html#a1d7c7a857bff7d91a532c811ecaf08a2',1,'osl::rating::BradleyTerry::kisen_filename()'],['../probability_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;probability.cc'],['../ratingstat_8cc.html#a7d206154015344334542008b65b9a110',1,'kisen_filename():&#160;ratingstat.cc']]],
  ['kisen_5fstart',['kisen_start',['../classosl_1_1rating_1_1BradleyTerry.html#adb84216c75da157172c0beae9901d122',1,'osl::rating::BradleyTerry::kisen_start()'],['../ratingstat_8cc.html#a986af9c47cde7151fd744d6b235d3d14',1,'kisen_start():&#160;ratingstat.cc']]],
  ['kmove',['kmove',['../classosl_1_1record_1_1ki2_1_1InputStream.html#af78116db5d99c09a067130df2155fa1b',1,'osl::record::ki2::InputStream']]],
  ['knight_5fadvance',['knight_advance',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aeba406eec6c99383a0400c27357a32e9',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fbonus',['knight_bonus',['../structosl_1_1eval_1_1MinorPieceDebugInfo.html#a1ce25ac27db449a3fedd83d5d350215c',1,'osl::eval::MinorPieceDebugInfo']]],
  ['knight_5fcheck',['knight_check',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a764c08e418edc7b632d708c163337ffa',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fcheck_5fbonus',['knight_check_bonus',['../structosl_1_1eval_1_1ProgressDebugInfo.html#a12766e07d3848aa0470e14f1a84e72f4',1,'osl::eval::ProgressDebugInfo']]],
  ['knight_5fdrop',['knight_drop',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a9565549637d50a8a90b560569fdb45c1',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5ffork_5fsquares',['knight_fork_squares',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#aef07b44ed27f2c85681175bc5378162c',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fhead',['knight_head',['../classosl_1_1eval_1_1ml_1_1OpenMidEndingEval.html#a80203477136176d1fdfda0cc4beaa0ae',1,'osl::eval::ml::OpenMidEndingEval']]],
  ['knight_5fon_5fstand',['knight_on_stand',['../classosl_1_1eval_1_1MinorPieceBonus.html#a2edbb8b0bea77db4f87100183f5e8dc4',1,'osl::eval::MinorPieceBonus']]],
  ['knight_5fpieces',['knight_pieces',['../classosl_1_1record_1_1MiniBoard.html#a7b1f0fa9a42ec524d6c0df9813234947',1,'osl::record::MiniBoard']]],
  ['knight_5ftable',['knight_table',['../classosl_1_1eval_1_1ml_1_1GoldFeatures.html#addd0581a233acd454a6dc0ad67895865',1,'osl::eval::ml::GoldFeatures']]]
];
